package com.fusion.fusionsdk.view;

import android.app.Activity;
import android.content.Context;
import android.view.View;
import android.widget.RelativeLayout;

import com.fusion.fusionsdk.utils.Constants;
import com.fusion.fusionsdk.utils.EventUtils;
import com.leyou.fusionsdk.FusionAdSDK;
import com.leyou.fusionsdk.ads.banner.BannerAd;
import com.leyou.fusionsdk.ads.banner.BannerAdListener;
import com.leyou.fusionsdk.model.AdCode;

import io.flutter.app.FlutterApplication;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.platform.PlatformView;


public class BannerAdView implements PlatformView {

    private EventChannel.EventSink mEventSink;
    private RelativeLayout mAdContainer;
    private BannerAd mBannerAd;


    public BannerAdView(Context context, BinaryMessenger binaryMessenger, int id, String codeId, int width, int height) {
        super();
        EventChannel eventChannel = new EventChannel(binaryMessenger, Constants.VIEW_EVENT + id);
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object o, EventChannel.EventSink eventSink) {
                mEventSink = eventSink;
            }

            @Override
            public void onCancel(Object o) {
            }
        });

        Activity activity = ((FlutterApplication) context.getApplicationContext()).getCurrentActivity();
        mAdContainer = new RelativeLayout(context);
        AdCode.Builder builder = new AdCode.Builder()
                .setCodeId(codeId);
        if (width > 0 && height > 0) {
            builder.setImgAcceptedSize(width, height);
        }

        AdCode adCode = builder.build();
        FusionAdSDK.loadBannerAd(activity, adCode, mAdContainer, new BannerAdListener() {
            @Override
            public void onBannerAdLoad(BannerAd bannerAd) {

                mEventSink.success(EventUtils.buildEventMap(Constants.ON_AD_LOAD));
                mBannerAd = bannerAd;
            }

            @Override
            public void onAdClicked(View view) {
                mEventSink.success(EventUtils.buildEventMap(Constants.ON_AD_CLICK));
            }

            @Override
            public void onAdShow() {
                mEventSink.success(EventUtils.buildEventMap(Constants.ON_AD_SHOW));
            }

            @Override
            public void onAdClosed() {
                mEventSink.success(EventUtils.buildEventMap(Constants.ON_AD_CLOSE));
            }

            @Override
            public void onError(int i, int i1, String s) {
                mEventSink.success(EventUtils.buildEventErrorMap(i1, s));
            }
        });
    }

    public BannerAdView(Context context, BinaryMessenger binaryMessenger, int id, String codeId) {
        this(context, binaryMessenger, id, codeId, -1, -1);
    }

    @Override
    public View getView() {
        return mAdContainer;
    }

    @Override
    public void dispose() {
        if (null != mBannerAd) {
            mBannerAd.destroy();
            mBannerAd = null;
        }
    }
}
