import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'fusion_ad_sdk.dart';

class BannerAdView extends StatelessWidget {
  final String codeId;
  final AdCallback onAdLoad;
  final AdCallback onAdShow;
  final AdCallback onAdClick;
  final AdCallback onAdClose;
  final AdErrorCallback onError;

  BannerAdView(
      {
        Key key,
        this.codeId,
        this.onAdLoad,
        this.onAdShow,
        this.onAdClick,
        this.onAdClose,
        this.onError})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    Widget banner;
    if (defaultTargetPlatform == TargetPlatform.android) {
      banner = AndroidView(
        viewType: 'com.fusion.ad/view',
        creationParams: {
          "type":2,
          "codeId": codeId
        },
        creationParamsCodec: const StandardMessageCodec(),
        onPlatformViewCreated: _onPlatformViewCreated,
      );
    }else {
      banner = Text("未支持的类型");
    }

    return Container(
      width: 420,
      height: 75,
      child: banner,
    );
  }

  void _onPlatformViewCreated(int id) {
    EventChannel eventChannel = EventChannel("com.fusion.ad/view_event_$id");
    eventChannel.receiveBroadcastStream().listen((event) {
      switch (event["event"]) {
        case "onAdLoad":
          onAdLoad?.call();
          break;
        case "onAdShow":
          onAdShow?.call();
          break;
        case "onAdClick":
          onAdClick?.call();
          break;
        case "onAdClose":
          onAdClose?.call();
          break;
        case "onError":
          onError?.call( event["code"], event["message"]);
          break;
      }
    });
  }
}
